@@ -125,7 +125,7 @@ ODOO_VERSION_INFO = {
         "pkg_version_specifier": ">=16.0dev,<16.1dev",
         "addons_ns": "odoo.addons",
         "namespace_packages": None,
-        "python_requires": ">=3.8",
+        "python_requires": ">=3.10",
         "universal_wheel": False,
         "git_postversion_strategy": STRATEGY_DOT_N,
     },
@@ -135,6 +135,13 @@ ODOO_VERSION_INFO = {
 def _get_odoo_version_info(addons_dir, odoo_version_override=None):
     """Detect Odoo version from an addons directory"""
     odoo_version_info = None
+    if odoo_version_override:
+        try:
+            odoo_version_info = ODOO_VERSION_INFO[odoo_version_override]
+        except KeyError:
+            raise DistutilsSetupError(
+                "Unsupported Odoo version: {}".format(odoo_version_override)
+            )
     addons = os.listdir(addons_dir)
     for addon in addons:
         addon_dir = os.path.join(addons_dir, addon)
@@ -153,6 +160,13 @@ def _get_odoo_version_info(addons_dir, odoo_version_override=None):
                     "in %s)" % (addons_dir, addon)
                 )
             odoo_version_info = addon_odoo_version_info
+    if odoo_version_info is None:
+        raise DistutilsSetupError(
+            "Could not determine Odoo version from {}, "
+            "probably because no installable addon was found. "
+            "Please use 'odoo_version_override' or "
+            "add an installable addon.".format(addons_dir)
+        )
     return odoo_version_info
 
 
